package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````,"D```````!``````````%C!````
M`````````$``.``-`$``'0`<``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````.@9````````Z!D`````````
M$`````````$````%`````"``````````(``````````@````````C4,`````
M``"-0P`````````0`````````0````0`````<`````````!P`````````'``
M``````"(1@```````(A&`````````!`````````!````!@```,"[````````
MP,L```````#`RP```````&@$````````D`0`````````$`````````(````&
M````T+L```````#0RP```````-#+``````````(``````````@````````@`
M````````!`````0````X`P```````#@#````````.`,````````P````````
M`#``````````"``````````$````!````&@#````````:`,```````!H`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````,``````````P``````````@`````````4.5T9`0`
M``#`L````````,"P````````P+`````````$`0````````0!````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````P+L```````#`RP```````,#+````
M````0`0```````!`!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````(`````4```!'3E4``@``P`0````#````````
M``*``,`$`````0`````````$````%`````,```!'3E4`NBI`?#%5!96:4,05
M_8'">7(3P=L$````$`````$```!'3E4```````,````"```````````````1
M````1`````0````(````(!`0``5`!(0H`@`$@(8`A(*)``()(`0(B(`10;H`
M`@@`````1````$<```!*````2P```%,```!4````50````````!7````6```
M`%D```!:````7````%X``````````````&[%WQ_.WD<M:W^:?"[%F[;49-1\
M(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@F4_#FVL)0]9G
MK\QF0D75[(D'<-,S8MOM%8PES`TZEPM^J9R;T67.;>"G`@IK&IY0H^#[20``
M`````````````````````````````*T"```2````````````````````````
M`!0"```2`````````````````````````(P````1````````````````````
M`````)0"```2`````````````````````````#X!```2````````````````
M`````````.\!```2`````````````````````````%`"```2````````````
M``````````````$````@`````````````````````````+@!```2````````
M`````````````````&<````2`````````````````````````,4!```2````
M`````````````````````)0````2`````````````````````````(T"```2
M`````````````````````````-\"```2``````````````````````````0"
M```2`````````````````````````-(````2````````````````````````
M`.(````2`````````````````````````#`!```2````````````````````
M`````'$!```2`````````````````````````&H!```2````````````````
M`````````(H````1`````````````````````````(D#```2````````````
M`````````````!`````@`````````````````````````,4"```2````````
M`````````````````+("```2`````````````````````````+T````2````
M`````````````````````"P````@`````````````````````````)T````2
M`````````````````````````*L````2`````````````````````````*D!
M```2`````````````````````````+<"```2````````````````````````
M`.@````6`````````````````````````/L````2````````````````````
M`````&,"```2`````````````````````````!8!```2````````````````
M`````````-`"```2`````````````````````````)H!```2````````````
M`````````````/T!```2`````````````````````````-$!```2````````
M`````````````````$4!```2`````````````````````````"<!```2````
M`````````````````````'X!```2`````````````````````````)\"```2
M`````````````````````````-X!```2`````````````````````````(4!
M```2`````````````````````````#4"```2````````````````````````
M`'D````2`````````````````````````),!```2````````````````````
M`````(P!```2`````````````````````````)P````2````````````````
M`````````,H!```2`````````````````````````"`"```2````````````
M`````````````($"```2`````````````````````````+T!```2````````
M`````````````````-D````2`````````````````````````,0````2````
M`````````````````````*(!```1`````````````````````````'0"```1
M`````````````````````````*0````2`````````````````````````&(!
M```2``````````````````````````L!```2````````````````````````
M`%0!```2`````````````````````````$$"```2````````````````````
M`````$8````2`````````````````````````.@"```2````````````````
M`````````+,````2`````````````````````````-@!```2````````````
M`````````````)(#```2`!``X%T```````#7`````````.<#```2`!``T%,`
M``````#7!P```````%,````2`!``("<````````.`@````````D#```2`!``
M`$@````````)`````````"<#```2`!``L%L````````P`@````````T$```2
M`!``$$@````````2`@```````,T#```0`!H`*-```````````````````!H#
M```2`!``,$H````````R`````````#T#```2`!``(%````````!I````````
M`)X#```1`!(``'`````````$`````````+H#```2`!``$%\```````"W`0``
M`````,4#```2`!``\$8````````I`````````.(#```0`!H`4-``````````
M`````````/L#```2`!``L%(````````9`0```````"0$```2`!``D%``````
M``#``````````*T#```0`!D``-```````````````````&$#```2`!``<$H`
M``````!!`0```````/0#```0`!D`*-```````````````````!H$```1`!D`
M(-`````````(`````````+,#```2`!``,"D````````F`````````-D#```2
M`!``P%X```````!&`````````*\#```@`!D``-```````````````````'<#
M```2`!``D%(````````>`````````%@````B````````````````````````
M`$L#```2`!``($<```````#=`````````&T#```2`!``T&````````"5`@``
M`````"P$```2`!``P$L```````!;!`````````!?7V=M;VY?<W1A<G1?7P!?
M251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!?7VQI8F-?<W1A<G1?;6%I;@!?7V-X85]F:6YA;&EZ90!?7W)E
M9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]F86EL`%]?96YV:7)O;@!S=')N
M8VUP`&QS=&%T-C0`86-C97-S`&]P96YD:7(`<F5A9&1I<C8T`'-T<FQE;@!?
M7W-P<FEN=&9?8VAK`'5N;&EN:P!C;&]S961I<@!R;61I<@!03%]C=7)R96YT
M7V-O;G1E>'0`8F]O=%]$>6YA3&]A9&5R`%!E<FQ?;F5W6%,`4&5R;%]N97=8
M4U]F;&%G<P!R96%D;&EN:P!097)L7W-V7W-E='!V`&UE;6-H<@!097)L7W-V
M7W-E='!V;@!?7VUE;6UO=F5?8VAK`')E86QL;V,`9V5T<&ED`%]?;65M8W!Y
M7V-H:P!S=')C:'(`<W1R9'5P`'-T<G1O:P!S=')C;7``<W1R<F-H<@!S=&1E
M<G(`7U]V9G!R:6YT9E]C:&L`97AI=`!L<V5E:S8T`')E860`9V5T=6ED`'-T
M<G-T<@!M:V1I<@!?7V5R<FYO7VQO8V%T:6]N`%]?9G!R:6YT9E]C:&L`;W!E
M;C8T`%!E<FQ?9W9?9F5T8VAP=@!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO
M8V]N=&5X=`!097)L7VUG7W-E=`!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R
M:U]U;FQO8VL`4&5R;%]A=&9O<FM?;&]C:P!03%]D;U]U;F1U;7``4&5R;%]S
M869E<WES;6%L;&]C`'!E<FQ?<&%R<V4`<&5R;%]D97-T<G5C=`!P97)L7V9R
M964`4&5R;%]S>7-?=&5R;0!P97)L7V%L;&]C`'!E<FQ?8V]N<W1R=6-T`'!E
M<FQ?<G5N`&UE;6-P>0!L:6)P97)L+G-O+C4N,S@`;&EB8RYS;RXV`'!A<E]C
M=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%A37TEN=&5R;F%L<U]005)?0D]/
M5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER
M;F%M90!S:&%?9FEN86P`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R
M7V-L96%N=7``7TE/7W-T9&EN7W5S960`7U]D871A7W-T87)T`'-H85]U<&1A
M=&4`>'-?:6YI=`!?7V)S<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M
M<&1I<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY
M7W!A<E]P;`!P87)?9&EE`'!A<E]I;FET7V5N=@!'3$E"0U\R+C$T`$=,24)#
M7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N,S,`1TQ)0D-?,BXS+C(`1TQ)0D-?
M,BXS+C0`1TQ)0D-?,BXR+C4````!``$``@`!``(``P`!``$``@`$``(``@`"
M``$``0`"``(``0`#``(``@`"``$``0`"``(``0`%``(``P`!``$``0`!``$`
M`0`"``(``@`!``(``@`!``(``@`!``8``@`"``4``@`!``$``@`"``,``@`!
M``(``@`!``,``0`'``@``@`"``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`"``$``0`!`````0`'`/\"```0````````
M`)21E@8```@`.00``!````"TD98&```'`$0$```0````%&EI#0``!@!/!```
M$````+.1E@8```4`600``!````!R&6D)```$`&0$```0````=!EI"0```P!P
M!```$````'4::0D```(`?`0```````#`RP````````@`````````$"H`````
M``#(RP````````@`````````T"D````````(T`````````@`````````"-``
M```````@T`````````@`````````^'(```````"@SP````````8````#````
M``````````"HSP````````8````'``````````````"PSP````````8````(
M``````````````"XSP````````8````7``````````````#`SP````````8`
M```;``````````````#(SP````````8```!;``````````````#0SP``````
M`!(````@``````````````#8SP````````8````A``````````````#@SP``
M``````8````B``````````````#HSP````````8````Y``````````````#P
MSP````````8````Z``````````````#XSP````````8```!`````````````
M``#HS0````````<````!``````````````#PS0````````<````"````````
M``````#XS0````````<````$````````````````S@````````<````%````
M```````````(S@````````<````&```````````````0S@````````<````)
M```````````````8S@````````<````*```````````````@S@````````<`
M```+```````````````HS@````````<````,```````````````PS@``````
M``<````-```````````````XS@````````<````.``````````````!`S@``
M``````<````/``````````````!(S@````````<````0``````````````!0
MS@````````<````1``````````````!8S@````````<````2````````````
M``!@S@````````<````3``````````````!HS@````````<````4````````
M``````!PS@````````<````6``````````````!XS@````````<````8````
M``````````"`S@````````<````9``````````````"(S@````````<````:
M``````````````"0S@````````<````<``````````````"8S@````````<`
M```=``````````````"@S@````````<````>``````````````"HS@``````
M``<````?``````````````"PS@````````<````C``````````````"XS@``
M``````<````D``````````````#`S@````````<````E``````````````#(
MS@````````<````F``````````````#0S@````````<````G````````````
M``#8S@````````<````H``````````````#@S@````````<````I````````
M``````#HS@````````<````J``````````````#PS@````````<````K````
M``````````#XS@````````<````L````````````````SP````````<````M
M```````````````(SP````````<````N```````````````0SP````````<`
M```O```````````````8SP````````<````P```````````````@SP``````
M``<````Q```````````````HSP````````<````R```````````````PSP``
M``````<````S```````````````XSP````````<````T``````````````!`
MSP````````<````U``````````````!(SP````````<````V````````````
M``!0SP````````<````W``````````````!8SP````````<````X````````
M``````!@SP````````<````[``````````````!HSP````````<````\````
M``````````!PSP````````<````]``````````````!XSP````````<````^
M``````````````"`SP````````<````_``````````````"(SP````````<`
M``!!``````````````"0SP````````<```!"``````````````"8SP``````
M``<```!#````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!:&O``!(A<!T`O_02(/$",,``````/\ULJT``/\EM*T`
M``\?0`#S#Q[Z:`````#IXO___V:0\P\>^F@!````Z=+___]FD/,/'OIH`@``
M`.G"____9I#S#Q[Z:`,```#ILO___V:0\P\>^F@$````Z:+___]FD/,/'OIH
M!0```.F2____9I#S#Q[Z:`8```#I@O___V:0\P\>^F@'````Z7+___]FD/,/
M'OIH"````.EB____9I#S#Q[Z:`D```#I4O___V:0\P\>^F@*````Z4+___]F
MD/,/'OIH"P```.DR____9I#S#Q[Z:`P```#I(O___V:0\P\>^F@-````Z1+_
M__]FD/,/'OIH#@```.D"____9I#S#Q[Z:`\```#I\O[__V:0\P\>^F@0````
MZ>+^__]FD/,/'OIH$0```.G2_O__9I#S#Q[Z:!(```#IPO[__V:0\P\>^F@3
M````Z;+^__]FD/,/'OIH%````.FB_O__9I#S#Q[Z:!4```#IDO[__V:0\P\>
M^F@6````Z8+^__]FD/,/'OIH%P```.ER_O__9I#S#Q[Z:!@```#I8O[__V:0
M\P\>^F@9````Z5+^__]FD/,/'OIH&@```.E"_O__9I#S#Q[Z:!L```#I,O[_
M_V:0\P\>^F@<````Z2+^__]FD/,/'OIH'0```.D2_O__9I#S#Q[Z:!X```#I
M`O[__V:0\P\>^F@?````Z?+]__]FD/,/'OIH(````.GB_?__9I#S#Q[Z:"$`
M``#ITOW__V:0\P\>^F@B````Z<+]__]FD/,/'OIH(P```.FR_?__9I#S#Q[Z
M:"0```#IHOW__V:0\P\>^F@E````Z9+]__]FD/,/'OIH)@```.F"_?__9I#S
M#Q[Z:"<```#I<OW__V:0\P\>^F@H````Z6+]__]FD/,/'OIH*0```.E2_?__
M9I#S#Q[Z:"H```#I0OW__V:0\P\>^F@K````Z3+]__]FD/,/'OIH+````.DB
M_?__9I#S#Q[Z:"T```#I$OW__V:0\P\>^F@N````Z0+]__]FD/,/'OIH+P``
M`.GR_/__9I#S#Q[Z:#````#IXOS__V:0\P\>^F@Q````Z=+\__]FD/,/'OIH
M,@```.G"_/__9I#S#Q[Z:#,```#ILOS__V:0\P\>^F@T````Z:+\__]FD/,/
M'OIH-0```.F2_/__9I#S#Q[Z:#8```#I@OS__V:0\P\>^O\E'JP``&8/'T0`
M`/,/'OK_)2ZJ``!F#Q]$``#S#Q[Z_R4FJ@``9@\?1```\P\>^O\E'JH``&8/
M'T0``/,/'OK_)1:J``!F#Q]$``#S#Q[Z_R4.J@``9@\?1```\P\>^O\E!JH`
M`&8/'T0``/,/'OK_)?ZI``!F#Q]$``#S#Q[Z_R7VJ0``9@\?1```\P\>^O\E
M[JD``&8/'T0``/,/'OK_)>:I``!F#Q]$``#S#Q[Z_R7>J0``9@\?1```\P\>
M^O\EUJD``&8/'T0``/,/'OK_)<ZI``!F#Q]$``#S#Q[Z_R7&J0``9@\?1```
M\P\>^O\EOJD``&8/'T0``/,/'OK_);:I``!F#Q]$``#S#Q[Z_R6NJ0``9@\?
M1```\P\>^O\EIJD``&8/'T0``/,/'OK_)9ZI``!F#Q]$``#S#Q[Z_R66J0``
M9@\?1```\P\>^O\ECJD``&8/'T0``/,/'OK_)8:I``!F#Q]$``#S#Q[Z_R5^
MJ0``9@\?1```\P\>^O\E=JD``&8/'T0``/,/'OK_)6ZI``!F#Q]$``#S#Q[Z
M_R5FJ0``9@\?1```\P\>^O\E7JD``&8/'T0``/,/'OK_)5:I``!F#Q]$``#S
M#Q[Z_R5.J0``9@\?1```\P\>^O\E1JD``&8/'T0``/,/'OK_)3ZI``!F#Q]$
M``#S#Q[Z_R4VJ0``9@\?1```\P\>^O\E+JD``&8/'T0``/,/'OK_)2:I``!F
M#Q]$``#S#Q[Z_R4>J0``9@\?1```\P\>^O\E%JD``&8/'T0``/,/'OK_)0ZI
M``!F#Q]$``#S#Q[Z_R4&J0``9@\?1```\P\>^O\E_J@``&8/'T0``/,/'OK_
M)?:H``!F#Q]$``#S#Q[Z_R7NJ```9@\?1```\P\>^O\EYJ@``&8/'T0``/,/
M'OK_)=ZH``!F#Q]$``#S#Q[Z_R76J```9@\?1```\P\>^O\ESJ@``&8/'T0`
M`/,/'OK_)<:H``!F#Q]$``#S#Q[Z_R6^J```9@\?1```\P\>^O\EMJ@``&8/
M'T0``/,/'OK_):ZH``!F#Q]$``#S#Q[Z_R6FJ```9@\?1```\P\>^O\EGJ@`
M`&8/'T0``/,/'OK_)9:H``!F#Q]$``#S#Q[Z_R6.J```9@\?1```\P\>^O\E
MAJ@``&8/'T0``/,/'OK_)7ZH``!F#Q]$``#S#Q[Z54B)Y4%44TB#[#")?=Q(
MC7W<2(EUT$B-==!(B57(2(U5R&1(BP0E*````$B)1>@QP.B&____2(LU1Z@`
M`$B+/7BH``!(B?+H`#P``$B+!7FH``"`.``/A!H!``!(BP5)J```9$B+`("(
M.@0```.+1=R->`2-6`-(8_](P><#Z+G^__](BTW01(M%W$B)QDB)!8^H``!(
MBP%(B09(C04?2@``2(E&"$B-!4^H``!(BP!(B4802(T%"4H``$B)1AA!@_@!
M#XXH`0``2(/!"$&#P`.X!````&8/'T0``$B+.4ACT(/``4B#P0A(B3S61#G`
M=>I(F$B+/1FH``!%,<!(B?%(QP3&`````(G:2(TU*AL``.B5^___A<`/A(<`
M``!(BSWNIP``3(UEY.AM_?__3(GF2(T]1D@``(G#,<#H"A@``$B%P'1P2(L]
MQJ<``.@Y^___Z+3\__](BT7H9$@K!"4H````#X6:````2(/$,(G86T%<7</H
M,?S__TB)!9*G``!(B<=(A<!T<>B=_/__2(L%%J<``&1(BQ#&@BX)````Z;W^
M__](BSUGIP``Z'K[___I:/___TB+/5ZG``!(A?]T"NCT-```Z7K___](C3U@
M1P``3(GFZ'`7``!(B04YIP``2(G'2(7`#X18____Z]*X!````.GW_O__OP$`
M``#HU_K__^C2_/__9I#S#Q[Z,>U)B=%>2(GB2(/D\%!413'`,<E(C3W1_?__
M_Q6CI@``]&8N#Q^$``````!(C3W!I@``2(T%NJ8``$@Y^'052(L%/J8``$B%
MP'0)_^`/'X``````PP\?@`````!(C3V1I@``2(TUBJ8``$@I_DB)\$C![C](
MP?@#2`'&2-'^=!1(BP4%I@``2(7`=`C_X&8/'T0``,,/'X``````\P\>^H`]
M3:8```!U*U5(@SWBI0```$B)Y70,2(L]%J8``.BI^?__Z&3____&!26F```!
M7<,/'P###Q^``````/,/'OKI=____P\?@`````!52(GZ3(U'.$B)Y4%7059(
MC8U`_?__3(V-P/W__T%52(G/05132('LF`(``&1(BP0E*````$B)1<@QP`\?
M1```08L`38L02(/'$$F#P`@/R(G`3(G62(E'\$R)T$C![B!(P>@H2<'J."4`
M_P``3`G028GR2,'F"$G!XAB!Y@``_P!%B=),"=!("?!(B4?X3#G/=:UF#V^-
M4/W__V8/;YU@_?__2(V%J/W__TB!P6@"``!F#V^5</W__V8/;RV?A0``#Q^`
M`````/,/;P!F#V_B9@]O4-A(@\`09@_O2(AF#^_"9@_OP68/;\AF#W/0'V8/
M<_$!9@_KP68/;\MF#V_<9@_;Q0\I0`A(.<AUNTR+"DR+6A!(BWH@2(M:&$R)
MR$R)R4R+A4C]__](P>D;2,'@!4@)R`.%0/W__TZ-A`.9>8):C8PXF7F"6DR)
MV$@QV$@C0@A(,=B-/`%(BTH(2(M""$F)^DC!Z`)(P>$>2`G!3(G82<'J&XG.
M2#'P3"'(3#'83`'`28GX2<'@!4T)T$:-)`!,B<A-B<A)P>@"2,'@'DV)Y4P)
MP$R+A5#]__])P>T;2#'!08G"2"'Y3XV$`YEY@EI(,?%,`<%-B>!)P>`%30GH
M3(NM6/W__T$!R$B)^4C![P)(P>$>18G`2HVT+IEY@EI("?E-B<5(,<B)STPA
MX$G![1M,,=!(`?!,B<9(P>8%3`GN3(NM8/W__P'&3(G@2<'L`DC!X!Z)]D^-
ME"J9>8):3`G@28GU2#'!2<'M&T&)Q$PAP4@Q^4P!T4F)\DG!X@5-">I,BZUH
M_?__00'*3(G!2<'H`DC!X1Y%B=)*C;POF7F"6DP)P4V)U4@QR$G![1M!B<A(
M(?!,,>!(`?A,B==(P><%3`GO3(NM</W__P''2(GP2,'N`DC!X!Z)_T^-I"R9
M>8):2`GP28G]2#'!2<'M&XG&3"'13#'!3`'A28G\2<'D!4T)[$R+K7C]__]!
M`<Q,B=%)P>H"2,'A'D6)Y$^-A"B9>8):3`G138GE2#'(2<'M&T&)RD@A^$@Q
M\$P!P$V)X$G!X`5-">A,BZV`_?__00'`2(GX2,'O`DC!X!Y%B<!*C;0NF7F"
M6D@)^$V)Q4@QP4G![1N)QTPAX4PQT4@!\4R)QDC!Y@5,">Y,BZV(_?__`<Y,
MB>%)P>P"2,'A'HGV3XV4*IEY@EI,">%)B?5(,<A)P>T;08G,3"'`2#'X3`'0
M28GR2<'B!4T)ZDR+K9#]__]!`<),B<!)P>@"2,'@'D6)TDJ-O"^9>8):3`G`
M38G52#'!2<'M&T&)P$@A\4PQX4@!^4R)UTC!YP5,">],BZV8_?__`<](B?%(
MP>X"2,'A'HG_3XVD+)EY@EI("?%)B?U(,<A)P>T;B<Y,(=!,,<!,`>!)B?Q)
MP>0%30GL3(NMH/W__T$!Q$R)T$C!X!Y)P>H"18GD3XV$*)EY@EI,"=!-B>5(
M,<%)P>T;08G"2"'Y2#'Q3`'!38G@2<'@!4T)Z$R+K:C]__]!`<A(B?E(P>\"
M2,'A'D6)P$J-M"Z9>8):2`GY38G%2#'(2<'M&XG/3"'@3#'02`'P3(G&2,'F
M!4P)[DR+K;#]__\!QDR)X$G![`)(P>`>B?9/C90JF7F"6DP)X$F)]4@QP4G!
M[1M!B<1,(<%(,?E,`=%)B?))P>(%30GJ3(NMN/W__T$!RDR)P4C!X1Y)P>@"
M18G22HV\+YEY@EI,"<%-B=5(,<A)P>T;08G(2"'P3#'@2`'X3(G72,'G!4P)
M[TR+K<#]__\!QTB)\$C![@)(P>`>B?]/C:0LF7F"6D@)\$F)_4@QP4G![1N)
MQDPAT4PQP4P!X4F)_$G!Y`5-">Q&C30A3(G12<'J`DC!X1Y,"=%,BY7(_?__
M2#'(08G,2"'X3XV$$)EY@EI-B?)(,?!)P>H;3`'`38GP2<'@!4T)T$R+E=#]
M__]!`<!(B?A(P>`>2,'O`D6)P$J-M!:9>8):2`GX38G"2#'!2<'J&XG'3"'Q
M3#'A2`'.3(G!2,'A!4P)T4V)\DG![@))P>(>B<E-"?)(`<Y(BXW8_?__3#'0
M08GU3"'`28V,#)EY@EI-B>Q(,?A)P>P;2`'(3(GI2,'A!4P)X8G)2`'(3(G!
M2<'H`DC!X1Y!B<1,"<%-B=!%B=)),<A$,<9,BX7@_?__2HV\!Z'KV6Y-B>!(
M`?=,B>9)P>@;2,'F!4P)QHGV2`'W3(GN2,'F'DG![0)!B?A,`Y7H_?__3`GN
M28G-B<E(`XWP_?__23'U1#'H38G%38V4`J'KV6Y,B<!)P>T;2,'@!4P)Z(G`
M20'"3(G@2<'L`DC!X!Y%B=5,">!)B?2)]D@#M?C]__]),<1$,>=-B>Q(C;PY
MH>O9;DR)Z4G![!M(P>$%3`GAB<E(`<],B<%)P>@"2,'A'D&)_$P)P4F)P(G`
M23'(13'038GB3HV$!J'KV6Y,B>9)P>H;2,'F!4P)UHGV20'P3(GN2<'M`DC!
MYAY%B<),">Y)B<U(`X4`_O__B<E),?5(`XT(_O__1#'O38G52(V\.*'KV6Y,
MB=!)P>T;2,'@!4P)Z(G`2`''3(G@2<'L`DC!X!Y!B?U,">!)B?2)]D@#M1#^
M__]),<1%,>!-B>Q.C80!H>O9;DR)Z4G![!M(P>$%3`GAB<E)`<A,B=%)P>H"
M2,'A'D6)Q$P)T4F)PHG`2`.%&/[__TDQRD0QUTV)XDB-O#ZAZ]EN3(GF2<'J
M&TC!Y@5,"=:)]D@!]TR)[DG![0)(P>8>08GZ3`GN28G-B<E),?5(`XT@_O__
M13'H38G53HV$`*'KV6Y,B=!)P>T;2,'@!4P)Z(G`20'`3(G@2<'L`DC!X!Y%
MB<5,">!)B?2)]D@#M2C^__]),<1$,>=-B>Q(C;PYH>O9;DR)Z4G![!M(P>$%
M3`GAB<E(`<],B=%)P>H"2,'A'D&)_$P)T4F)PHG`2`.%,/[__TDQRD4QT$V)
MXDZ-A`:AZ]EN3(GF2<'J&TC!Y@5,"=:)]DD!\$R)[DG![0)(P>8>18G"3`GN
M28G-B<E),?5$,>]-B=5(C;PXH>O9;DR)T$C!X`5)P>T;2`.-./[__TP)Z(G`
M2`''3(G@2<'L`DC!X!Y!B?U,">!)B?2)]D@#M4#^__]),<1%,>!-B>Q.C80!
MH>O9;DR)Z4G![!M(P>$%3`GAB<E)`<A,B=%)P>H"2,'A'D6)Q$P)T4F)PHG`
M2`.%2/[__TDQRD0QUTV)XDB-O#ZAZ]EN3(GF2<'J&TC!Y@5,"=:)]D@!]TR)
M[DG![0)(P>8>08GZ3`GN28G-B<E),?5%,>A-B=5.C80`H>O9;DR)T$G![1M(
MP>`%3`GH2`.-4/[__XG`20'`3(G@2<'L`DC!X!Y%B<5,">!)B?2)]D@#M5C^
M__]),<1$,>=-B>Q(C;PYH>O9;DR)Z4G![!M(P>$%3`GAB<E(`<],B=%)P>H"
M2,'A'D&)_$P)T4F)PHG`2`.%8/[__TDQRD4QT$V)XDZ-A`:AZ]EN3(GF2<'J
M&TC!Y@5,"=:)]DD!\$R)[DG![0)(P>8>18G"3`GN28G-B<E),?5$,>]-B=5(
MC;PXH>O9;DR)T$G![1M(P>`%3`GHB<!(`<=,B>!(P>`>2<'L`D&)_4@#C6C^
M__],">!)B?2)]D@#M7#^__]),<1%,>!.C:0!H>O9;DR)Z4V)Z$G!Z!M(P>$%
M3`G!B<E)`<Q,B=%)P>H"2,'A'D6)X$P)T4F)PHG`2`.%>/[__TDQRD0QUTV)
MPDB-O#ZAZ]EN3(G&2<'J&TC!Y@5,"=9-B>I)P>T"2<'B'@'W2(G.B<E-">J)
M_TPQUDV)UD6)U40QYDF)_$B-M#"AZ]EN2(GX2<'L&TC!X`5,">!$C20&3(G&
M2<'H`KC<O!N/2,'F'DP)QDD)]D&)\$TAPDDA_DT)UDR+E8#^__])`<),`=%-
MB>),`?%-B>9)P>(%2<'N&TT)\D$!RDB)^4C![P)(P>$>18G22`GY2`G.28G.
MB<],(>9-(<9)"?9(B[6(_O__2`'&3`'N38G53`'V38G62<'E!4G![AM-"?5)
MB<Y!`?5,B>9)P>P"2,'F'D6)[4P)YD&)]$D)]DTAUDPAX4P)\4R+M9#^__])
M`<9-`<9-B>A,`?%-B>Y)P>`%2<'N&TT)\$$!R$R)T4G!Z@)(P>$>18G`3`G1
M2`G.28G.08G*3"'N32'F20GV2(NUF/[__T@!QD@!_DR)QTP!]DV)QDC!YP5)
MP>X;3`GW28G.`?=,B>Y)P>T"2,'F'HG_3`GN08GU20GV32'&3"'I3`GQ3(NU
MH/[__TD!QDT!YDF)_$P!\4F)_DG!Y`5)P>X;30GT00',3(G!2<'H`DC!X1Y%
MB>1,"<%("<Y)B<Y!B<A((?Y-(>Y)"?9(B[6H_O__2`'&3`'638GB3`'V38GF
M2<'B!4G![AM-"?))B<Y!`?)(B?Y(P>\"2,'F'D6)TD@)_HGW20GV32'F2"'Y
M3`GQ3(NUL/[__TD!QDT![DV)U4P!\4V)UDG!Y05)P>X;30GU00'-3(GA2,'A
M'DG![`)%B>U,">%("<Y)B<Y!B<Q,(=9)(?Y)"?9(B[6X_O__2`'&3`'&38GH
M3`'V38GN2<'@!4G![AM-"?!)B<Y!`?!,B=9)P>H"2,'F'D6)P$P)UD&)\DD)
M]DTA[DPAT4P)\4R+M<#^__])`<9)`?Y,B<=,`?%-B<9(P><%2<'N&TP)]P'/
M3(GI2<'M`DC!X1Z)_TP)Z4@)SDF)SD&)S4PAQDTAUDD)]DB+M<C^__](`<9,
M`>9)B?Q,`?9)B?Y)P>0%2<'N&TT)]$F)SD$!]$R)QDG!Z`)(P>8>18GD3`G&
M08GP20GV22'^3"'!3`GQ3(NUT/[__TD!QDT!UDV)XDP!\4V)YDG!X@5)P>X;
M30GR00'*2(GY2,'O`DC!X1Y%B=)("?E("<Y)B<Z)STPAYDTAQDD)]DB+M=C^
M__](`<9,`>Y-B=5,`?9-B=9)P>4%2<'N&TT)]4F)SD$!]4R)YDG![`)(P>8>
M18GM3`GF08GT20GV32'63"'A3`GQ3(NUX/[__TD!QDT!QDV)Z$P!\4V)[DG!
MX`5)P>X;30GP00'(3(G12<'J`DC!X1Y%B<!,"=%("<Y)B<Y!B<I,(>Y-(>9)
M"?9(B[7H_O__2`'&2`'^3(G'3`'V38G&2,'G!4G![AM,"?=)B<X!]TR)[DG!
M[0)(P>8>B?],">Y!B?5)"?9-(<9,(>E,"?%,B[7P_O__20'&30'F28G\3`'Q
M28G^2<'D!4G![AM-"?1!`<Q,B<%)P>@"2,'A'D6)Y$P)P4@)SDF)SD&)R$@A
M_DTA[DD)]DB+M?C^__](`<9,`=9-B>),`?9-B>9)P>(%2<'N&TT)\DF)SD$!
M\DB)_DC![P)(P>8>18G22`G^20GVB?=-(>9((?E,"?%,B[4`____20'&30'N
M38G53`'Q38G62<'E!4G![AM-"?5!`<U,B>%)P>P"2,'A'D6)[4P)X4@)SDF)
MS$&)STPAUDDA_$D)]$B+M0C___](`<9,`<9-B>A,`>9-B>Q)P>`%2<'L&TT)
MX$$!\$R)UDG!Z@)(P>8>18G`3`G628G*08GT20GR32'J3"'A3`G13(N5$/__
M_TD!PD@#A1C___],`==-B<),`?A,B[TX____2`'/3(G!2<'J&TC!X05,"=&)
MR4@!STR)Z4G![0)(P>$>08GZ3`GI2`G.28G-08G.3"'&32'E20GU28UT!0!,
MB=!-B=5)P>T;2,'@!4P)Z(G`2`'&3(G`2<'H`DC!X!Y!B?5)"<"XUL%BRDPQ
MP3'Y2(N](/___T@!QTP!YTV)[$@!^4R)[TG![!M(P><%3`GG38G4B?](`?E)
MP>0>20''2<'J`HG/30GB38G$18G`33'403'T2(NU*/___T@!QDP!]DF)_DP!
MYDF)_$G![AM)P>0%30GT38GN2<'M`DG!YAY%B>1-"?5,B[4P____3`'F08GT
M20'&30'P38G633'N03'.3(GA30'P38GF2,'A!4G![AM,"?&)R4D!R$B)^4C!
M[P)(P>$>18G&2`G/1(G138GJ23'Z3`'Y3(N]0/___T$Q\DJ--!%,B?%-B?)(
MP>$%2<'J&TD!QTP)T8G)2`'.3(GA2<'L`DC!X1Y!B?),">%%B>Q)B?V)_TDQ
MS4T!_$R+O5C___]%,<5/C00L38G438G52<'M&TG!Y`5-">Q-B?5)P>X"2<'E
M'D6)Y$T)[DR+K4C___]-`>!%B<1)`<5,`>])B<V)R4TQ]4$Q]4R)YDP![TV)
MY4C!Y@5)P>T;3`GNB?9(`?=,B=9)P>H"2,'F'D&)_4P)UDR+E5#___])`<),
M`=%-B?)),?)%,<))`<=.C0013(GI38GJ2<'J&TC!X05,"=&)R4D!R$R)X4G!
M[`)(P>$>18G"20G,1(GQ28GVB?9-,>9,`?E,B[UH____03'^2HT\,4R)T4V)
MUDD!QTG![AM(P>$%3`GQB<E(`<],B>E)P>T"2,'A'D&)_DP)Z4R+K6#___])
M`<5,`>Y-B>5),<U%,<5.C00N3(GV38GU2<'M&TC!Y@5,">Z)]DD!\$R)UDG!
MZ@)(P>8>18G%20GR1(GF28G,B<E,`?Y-,=1,B[UX____03'\2HT\)DR)[DV)
M[$D!QTG![!M(P>8%3`GFB?9(`?=,B?9)P>X"2,'F'D&)_$P)]DR+M7#___])
M`<9,`?%-B=9),?9%,<9.C00Q3(GA38GF2<'N&TC!X05,"?&)R4D!R$R)Z4G!
M[0)(P>$>18G&20G-1(G128GRB?9-,>I,`?E,BWV(03'Z2HT\$4R)\4V)\DG!
MZAM(P>$%3`G1B<E(`<],B>%)P>P"2,'A'D&)^DP)X4R+98!)`<1,`>9-B>Q)
M`<=),<Q%,<1.C00F3(G638G42<'L&TC!Y@5,">:)]DD!\$R)]DG![@)(P>8>
M18G$20GV1(GN28G-B<E-,?5,`?Y,BWV803']2HT\+DR)YDV)Y4G![1M(P>8%
M3`GNB?9(`?=,B=9)P>H"2,'F'D&)_4P)UDR+59!)`<),`=%-B?)),?)%,<).
MC0013(GI38GJ2<'J&TC!X05,"=&)R4D!R$R)X4G![`)(P>$>18G"20G,1(GQ
M28GV20''33'F3`'YB?9,BWVH03'^3(G720'.3(G12,'O&TD!QTC!X05("?F)
MR4D!SDR)Z4G![0)(P>$>1(GW3`GI3(MMH$D!Q4P![DV)Y4DQS44QQ4Z-!"Y(
MB?Y)B?U)P>T;2,'F!4P)[HGV20'P3(G62<'J`DC!YAY%B<5)"?)$B>9)B<R)
MR4TQU$P!_D4Q]$V)[DP!YDV)[$G![AM)P>0%30GT28G^18GD3`'F2<'F'DC!
M[P)!B?1,"?=,BW6P20'&2`-%N$P!\4V)UDP!R$6)TDDQ_DP!T$4QQDV)X$P!
M\4V)YDG!X`5)P>X;30GP1`'!38GH2<'M`DG!X!Z)R4T)Q4F)^`-Z($TQZ$$!
MW4B)>B!$,<9)B<A,B6H82`'P2(G.2<'H&P-*"$C!Y@5(B4H(3`G&`?!(B0),
MB>!)P>P"2,'@'DP)X$0!V$B)0A!(BT7(9$@K!"4H````=1)(@<28`@``6T%<
M05U!7D%?7</HG>7__V9F+@\?A```````9I!52(GE05=!5D%505132(/L&$B)
M=<A(A?\/A+(```!(BP4+CP``3(LP387V#X2?````#[8'28G]A,!T!#P]=5%%
M,>1)BQY(A=MT+$UCY$V)]TR)XDR)[DB)W^ABX___A<!U!T*`/",]=$=)BU\(
M28/'"$B%VW7:2(/$&$B)V%M!7$%=05Y!7UW##Q^$``````!)B?Q!#[9$)`%)
M@\0!A,!T!#P]=>Y%*>SKF&8/'T0``$R)^4B+1<A*C5PC`4PI\4C!^0.)".NO
M9@\?A```````,=OKHF9F+@\?A```````D%5(B>532(G[2(VU4/___TB![*@`
M``!D2(L$)2@```!(B47H,<#HMN3__X7`=3J+E6C___^!X@#P``"!^@!```!T
M"('Z`*```'4@O@(```!(B=_H^>3__X7`#Y3`#[;`ZPD/'X``````,<!(BU7H
M9$@K%"4H````=09(BUWXR</H+.3__V9F+@\?A```````D%5(B>5!5T%6055!
M5%-(@>RH````9$B+!"4H````2(E%R#'`2(7_=`B`/P!(B?MU*$B+1<AD2"L$
M)2@````/A2P!``!(@<2H````6T%<05U!7D%?7<,/'P#HT^+__TF)Q4B%P'3+
M3(GOZ+/D__](A<`/A+H```"`>!,N3(U@$W4008!\)`$`=-T/'X0``````(!X
M$RX/A*X```!(B=_H;N+__TR)YTF)QNACXO__18U\!@)-8_],B?_HH^'__TV)
MX4F)V$R)^DF)QDB)Q[X"````,<!(C0U*+0``Z-'C__],B?=(C;4P____Z#+B
M__],B?>#^/]T$HN%2/___R4`\```/0!```!T8.B#X?__3(GWZ.OA__],B>_H
M`^3__TB%P`^%4/___V8N#Q^$``````!,B>_H:./__TB)W^A@X?__Z>O^__\/
M'P!!@'PD`2X/A4;___]!@'PD`@`/A`7____I-?___P\?`.B3_O__ZY[HK.+_
M_V9F+@\?A```````D/,/'OI52(T-!&T``$B--9<L``!(B>532(/L"$B+'4Z,
M``!(BQ5/C```9$B+.^@NX___9$B+.TB+7?A%,<E(C14,&```3(T%%RX``$B-
M-70L``#)3(G!Z87A__\/'T0``%5(B>5!5D%505132('L`!```$B##"0`2(/L
M$+K_#P``9$B+!"4H````2(E%V#'`3(VMT.___TB)^TF)]$B-/3@L``!,B>[H
ME>'__X7`?A:)P8/H`4ACT("\%=#O__\`=4>%P'4[2(L%I(L``$R)XDB)WF1(
MBSCH5>#__TB+1=AD2"L$)2@```!U44B!Q!`0``!;05Q!74%>7<-F#Q]$``")
MP68/'T0``$QC\;XO````3(GO3(GRZ&7?__](A<!TI4B+!4F+``!,B?%,B>I(
MB=YD2(LXZ/?@___KH.A@X?__54B)Y4%7059!54F)]4%44TB)^TB#["AD2(L$
M)2@```!(B47(,<`QP(`^/0^4P$D!Q4R)[^@7X/__2(UUQ$B)WTF)Q#'`Z(;[
M__](A<`/A`4!``!(B<=)B<;H\M___TPYX`^#T0```$QC1<1,BSV.B@``2<'@
M`P^V`X3`#X2G`0``/#T/A)\!``!(B=@/'T``#[90`4B#P`&$TG0%@/H]=>](
M*=A(F$J-?"`"38G&3(E%N$T#-^CFWO__28D&2(7`=%!)BP=,BT6X2(U+`4J+
M%``/M@.(`CP]=!N$P'4&ZQ4\/701#[8!2(/"`4B#P0&(`H3`=>O&`CTQP&8/
M'T0``$$/MDP%`(A,`@%(@\`!A,EU[DB+1<AD2"L$)2@````/A1<!``!(@\0H
M6T%<05U!7D%?7<,/'T``,<!F#Q]$``!!#[94!0!!B!0&2(/``832=>[KO@\?
M0`!,BSVAB0``38L/28,Y``^$PP```$R)R$4Q]F8/'T0``$B#P`A$B?)!@\8!
M2(,X`'7OC4H#2&/)2,'A`XL%]XD``(7`=6-(B<],B4VPQP7BB0```0```$B)
M3;CHZ=W__TB)QTB%P`^$3____TUCQDB+3;A(BW6P2<'@`TR)PDR)1;CH4N#_
M_TR+1;A)B0=(B<=!C48!1(EUQ$B82,<$QP````#I=_[__Y!,B<](B<[H!>#_
M_TF)!TB)QTB%P`^$^/[__TUCQDG!X`/KQ0\?1```,<#I=_[__[D0````13'V
MZ5?____H']___V9F+@\?A```````#Q]``/,/'OI(BP75B```2(L5UH@``$B-
M#6=I``!(C37Z*```9$B+..FGW___#Q^``````/,/'OI52(GE055!5%-(@>P`
M$```2(,,)`!(@>P`$```2(,,)`!(@^PH9$B+!"4H````2(E%V#'`2(V=T.__
M_TR-I<#?___H1=W__TR-#=0H``"Z`1```$B)WT&)P$B-#<8H``"^`@```#'`
MZ`#?__](B=^Z`!```$R)YN@`WO__,?^%P'@R1(UH`4B)PTUC[4R)[^B(W/__
M2(G'2(7`=!A(8]M,B>E,B>9(B=KHS]S__\8$&`!(B<=(BT789$@K!"4H````
M=1%(@<0H(```2(GX6T%<05U=P^@#WO__#Q\`\P\>^ND7____#Q^``````/,/
M'OI52(GE05=!5D%505132('L`!```$B##"0`2('LN````&1(BP0E*````$B)
M1<@QP$F)_$F)]4B-/0@H``!(C;4L[___Z!3X__^^+P```$R)YTB)P^A$W?__
M2(7`=#\QP$R)YDB-/>0G``#H'OS__TR)X$B+5<AD2"L4)2@````/A84!``!(
MC6786T%<05U!7D%?7<-F#Q^$``````!,B>],C2VT)P``Z"'=__],B>Y(B<?H
M5MW__TF)QDB%P'2?08`^``^$X@````\?0`!(A=MT$TR)]DB)W^@@W?__A<`/
MA*8```!,B??H\-O__TF-5`;_28G'23G6<@_K'9#&`@!(@^H!23G6=`6`.B]T
M[TR)]^C'V___28G'3(GGZ+S;__])C40'`4@]_P\```^'+/___TB#[`A,C;W`
M[___38GP,<!!5+H`$```O@(```!,B?](C0T'*```3(T-_B8``.@9W?__2(VU
M,.___TR)_^AZV___6EF%P'42BX5([___)0#P```]`(```'123(GN,?_H>-S_
M_TF)QDB%P`^$O?[__T&`/@`/A2+___](A=MT!8`[+G080;\!````3(TU@28`
M`.E2____9@\?1```@'L!`'2XZ^`/'X0``````+X!````3(G_Z*/<__^%P'6=
M3(G^2(T]5B8``.B0^O__3(G_Z,C;___I:/[__^C>V___9F8N#Q^$```````/
M'P#S#Q[Z5;XO````2(GE4TB)^TB#[`CH%MO__TB-4`%(A<!(#T7:2(G?2(M=
M^,GI?MO__V9F+@\?A```````#Q\`\P\>^E5(B>5!5%-(@>P`$```2(,,)`!(
M@^P09$B+!"4H````2(E%Z#'`2(7_#X3-````@#\`2(G[#X3!````Z#S:__](
MB<)(C4`!2#T`$```#X?A````3(VEX.___TR)YX/X"'(.B<%(B=[!Z0/S2*5(
MB?,QR:@$=`F+"XD/N00```"H`G0.1`^W!`MF1(D$#TB#P0*H`70'#[8$"X@$
M#TF-1!3_23G$<A+K%0\?0`#&``!(@^@!3#G@=`6`."]T[[XO````3(GGZ"+:
M__](A<!T+4DYQ')83(GGZ)#:__](BU7H9$@K%"4H````=4U(@<00$```6T%<
M7<,/'T0``$B+1>AD2"L$)2@```!U+4B!Q!`0``!(C3W))```6T%<7>E*VO__
M9BX/'X0``````,8``.NC#Q\`,<#KI.A/VO__9F8N#Q^$```````/'T``\P\>
M^E5(B>5!5T%6055!5$R-)9LD``!32(U=Q$B#[!AD2(L$)2@```!(B47(,<"0
M,<!(B=Y,B>?H<_3__TB%P'0V2(L%EX,``$AC5<1(BP!(C0302(M0"$B)$$B%
MTG302(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(TE/"0``)`QP$B)WDR)Y^@C
M]/__2(7`=#9(BP5'@P``2&-5Q$B+`$B-!-!(BU`(2(D02(72=-!(BU`02(/`
M"$B)$$B%TG7PZ[YF#Q]$``!,C27T(P``D#'`2(G>3(GGZ-/S__](A<!T-DB+
M!?>"``!(8U7$2(L`2(T$T$B+4`A(B1!(A=)TT$B+4!!(@\`(2(D02(72=?#K
MOF8/'T0``$R-):TC``"0,<!(B=Y,B>?H@_/__TB%P'0V2(L%IX(``$AC5<1(
MBP!(C0302(M0"$B)$$B%TG302(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(TE
M9",``)`QP$B)WDR)Y^@S\___2(7`=#9(BP57@@``2&-5Q$B+`$B-!-!(BU`(
M2(D02(72=-!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,C2TD(P``D#'`2(G>
M3(GOZ./R__](A<!T-DB+!0>"``!(8U7$2(L`2(T$T$B+4`A(B1!(A=)TT$B+
M4!!(@\`(2(D02(72=?#KOF8/'T0``$R-+8DB``"0,<!(B=Y,B>_HD_+__TB%
MP'0V2(L%MX$``$AC5<1(BP!(C0302(M0"$B)$$B%TG302(M0$$B#P`A(B1!(
MA=)U\.N^9@\?1```3(T]D"(``)`QP$B)WDR)_^A#\O__2(7`=#9(BP5G@0``
M2&-5Q$B+`$B-!-!(BU`(2(D02(72=-!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$
M``!,C35*(@``D#'`2(G>3(GWZ//Q__](A<!T-DB+!1>!``!(8U7$2(L`2(T$
MT$B+4`A(B1!(A=)TT$B+4!!(@\`(2(D02(72=?#KOF8/'T0``#'`2(G>2(T]
M_R$``.BG\?__2(7`=#I(BP7+@```2&-5Q$B+`$B-!-!(BU`(2(D02(72=,P/
M'T``2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```,<!(B=Y(C3U-(0``Z%?Q__](
MA<!T.DB+!7N```!(8U7$2(L`2(T$T$B+4`A(B1!(A=)TS`\?0`!(BU`02(/`
M"$B)$$B%TG7PZ[9F#Q]$``!(B=Y(C3UK(0``Z`GQ__](A<!T#4B)QDR)]S'`
MZ"?U__\QP$B)WDB-/5DA``#HYO#__TB%P'012(G&2(T]5R$``#'`Z`#U__](
MB=Y(C3U1(0``,<#HO_#__TB)QDB%P'0X3(GO,<#HW?3__TB+1<AD2"L$)2@`
M``!U1$B#Q!A,B>=(C34#(@``,<!;05Q!74%>05]=Z:_T__\QP$B)WDB-/0XA
M``#H;O#__TB%P'2\2(G&3(G_,<#HC/3__^NMZ.75__\/'T0``/,/'OI52(T]
M@R```$B)Y4B#[!!D2(L$)2@```!(B47X,<!(C77TZ"7P__](A<!T,`^V$(#Z
M,`^4P(32#Y3""="#\`$/ML!(BU7X9$@K%"4H````=0_)PV8/'X0``````#'`
MZ^+H=]7__P\?@`````#S#Q[Z54B)Y4B![-````!(B;58____2(F58/___TB)
MC6C___],B85P____3(F->/___X3`="`/*46`#RE-D`\I5:`/*5VP#REEP`\I
M;=`/*77@#RE]\&1(BP0E*````$B)A4C___\QP$B-11!(B?I(C8TP____2(F%
M./___[X"````2(V%4/___TB)A4#___](BP7!?@``QX4P____"````,>%-/__
M_S````!(BP!(B<?HVM/__[__````Z+#2__]52(GE055!5%-,C9PD``#__TB!
M[``0``!(@PPD`$PYW'7O2(/L&+H"````,?9D2(L$)2@```!(B478,<!!B?U(
MC9W0__[_Z-74__],C6#_3(GB2,'Z/TC!ZC!)C004#[?`2"G022G$#XB?````
M#Q\`,=),B>9$B>_HH]3__TB#^/\/A)P```"Z"``!`$B)WD2)[^@YTO__@_C_
M='E(F$B#^`=V5$B-1`/X2#G8<DI(C14+?@``ZQ)F#Q^$``````!(@^@!2#G8
M<B](BPI(.0AU[T@IV$P!X$B+5=AD2"L4)2@```!U2TB!Q!@``0!;05Q!75W#
M#Q]``$F![````0!)@?P``/__#X5D____2,?`_____^O"2(T]O1X``#'`Z!W^
M__](C3VB'@``,<#H#_[__^AZT___9BX/'X0``````/,/'OI52(GEZ*/3__^)
MQ^@<TO__2(7`=`-(BP!=PV:0\P\>^E5(B>5!5T%62(UUQ$%53(TM;!X``$%4
M28G\3(GO4TB#[!AD2(L$)2@```!(B47(,<#HANW__TB%P'0(@#@`2(G#=3%(
MBT7(9$@K!"4H````#X6Z````3(GF2(UEV$R)[S'`6T%<05U!7D%?7>E[\?__
M#Q\`3(GF2(G'Z$W2__](A<!T*$B+1<AD2"L$)2@```!U?4B-9=A;05Q!74%>
M05]=PV8N#Q^$``````!,B>?HB-'__TB)WTF)QNA]T?__38U\!@),B?_HP-#_
M_TB#[`A,B?I-B>!32(G'28G&3(T-UAP``$B-#=,=``"^`@```#'`Z.72__]8
M6DB+1<AD2"L$)2@```!U"$R)]NE)____Z#?2__\/'X``````\P\>^E5(C0UP
M'0``9D@/;L%(C0T!'0``2(GE05=!5DR-O;3^__]!54R)_D%44TB![$@!``!(
MB;VH_O__2(T]11P``&1(BP0E*````$B)1<A(C04O'```2,>%\/[__P````!(
MQX4H____`````$C'A=#^__\`````9D@/;LA(C07]'```9@]LP69(#V[02(T%
M]1P```\IA>#^__]F2`]NP4B-#8\<``!F2`]NV&8/;,)(C07;'```#Q&%"/__
M_V9(#V[!2(T-PQP``&9(#V[@9@]LPS'`#Q&%&/___V9(#V[!9@]LQ`\IA<#^
M___HK^O__TB%P'0,@#@`2(G##X4&!0``Z&G1__^)Q^CBS___2(7`#X0Y!```
M3(LP387V#X0M!```3(GWZ/7/__],C6P``4R)[TR)Z^@US___10^V!DB)A:#^
M__])B<1%A,!T4V:03(GJ10^VP$R)YS'`2(T-.!P``+X"````28/&`>A/T?__
M3#GK3(GJ10^V!D@/0]-(B=!,*>A(@\`"2#G02`]"PDDIU4F#Q`)-C6P%_D6$
MP'6O3(VM`/___TB-/7$;``#K%`\?@`````!)BWT(28/%"$B%_W0[3(G^,<#H
MT>K__TF)Q$B%P'3A@#@`=-Q(B<?HG.O__X7`=-!,B>?H(-#__TF)Q$B%P'5(
M#Q^$``````!,C:W@_O__38ME`$V%Y'0P08`\)``/A"4#``!,B>?H7>O__X7`
M#X4-`0``38ME"$F#Q0A-A>1UV`\?A```````3(GGZ-C.__](BYV@_O__28G%
M2(G?Z,;.__]%C;0%!`0``$UC]DR)]^@#SO__4TV)X$R-#2@:``!)B<5(C04G
M&P``3(GRO@(```!02(T-#AL``$R)[S'`Z"30__],B>^^P`$``.B7T/__7T%8
M@_C_=1+H2L___T2+"$&#^1$/A1(#``!(C84P____3(GO2(G&2(F%F/[__^B$
MS___B<.%P'1V2(N%J/[__TV)Z+X"````2(T5:!L``$B+"$B+!19Y``!(BS@Q
MP.@4S?__13'D2(M%R&1(*P0E*`````^%H@0``$B-9=A,B>!;05Q!74%>05]=
MPP\?0`!,B>=)@\4(Z,S.__])B<1(A<`/A+?^___IZ_[__P\?`(N%2/___R4`
M\```/0!````/A73___]$BZ5,____Z/;.__]!.<0/A5____^+A4C___\E_P$`
M`#W``0``#X5)____3(GWZ,_,__],B?Y(C3W%&0``28G$,<#HZ^C__TB%P`^$
M@@(``$B+C:C^__](B<9(BSGH</#__TB)A:#^__](A<`/A&`"``!(B[V@_O__
MZ#3-__](B<*#^`-^3$B+C:#^__](F$B--:H9``!(B960_O__2(U\`?SH*\[_
M_X7`=2=(BY60_O__@_H$#X0Y`P``2(N-H/[__XU"^TB8@#P!+P^$(P,``)!,
MB?Y,C3V5&```,<!,B?_H3.C__TB%P`^$`P(```^V`(3`#X3X`0``/#`/A/`!
M``!,B?](C369&0``,<#H3^S__TR-/6H9``#H4\S__T%73(GR38GH4$R-#0,8
M``"^`@```$R)YTB-#289```QP.@-SO__6%KK2F8/'X0``````.@[S?__@S@1
M=4GH$<S__X/#`4B#[`A-B>A!5TR-#;X7``!,B?),B>=32(T-\!@``+X"````
M4#'`Z,/-__](@\0@OL`!``!,B>?H,L[__X/X_W2M3(GOZ/7+__],B>9(C3UC
M%P``,<#HI.O__TR)Y^BL^?__Z=;]__\/'X``````13'DZ?C\__\/'X0`````
M`$B+O<#^__](C9W`_O__2(7_="8/'T0``#'`3(G^Z"[G__](A<!T!8`X`'5$
M2(M["$B#PPA(A?]UW[\-````NPT```!,C37;%P``0;T-````Z,O*__]!N%,`
M``!(B86@_O__28G$Z9;[__]F#Q]$``!(B<?H2,S__TF)QDB%P'2LZ4[[__](
MBX6H_O__38GHO@(```!(C14U&```2(L(2(L%(W8``$B+.#'`Z"'*___I"/W_
M_P\?0`!(B<?HT/C__TB+1<AD2"L$)2@````/A:$!``!(C6782(G?6T%<05U!
M7D%?7>G7R___#Q^``````$B+A:C^__](BP!(B86@_O__Z8K]__]F+@\?A```
M````2(N]H/[__S'V,<#H,,O__XG'A<`/A/;]__^)A:C^___H^_;__TB%P`^(
MXOW__XN]J/[__S'22(UP]DB)A:#^___H^LO__XN]J/[__[H&````2(VUNO[_
M_^B3R?__B[VH_O__2(N-H/[__TB#^`8/A?4```"!O;K^__\`0T%##X6,_?__
M9H&]OO[__TA%#X5]_?__,=)(C7'.B;VH_O__Z)S+__^+O:C^__^Z*````$B+
MG9C^__](B=[H,LG__TB#^"@/A:$```!(C07#%@``O@(```!-B>A,B?+&A5C_
M__\`2(T->Q8``$R-#5$5``!,B>=0,<!3Z&7+__]97NFQ_?__2(N%J/[__TB+
M4`A(A=(/A,K\__](B==(B96H_O__Z)O)__](@_@##X:Q_/__2(N5J/[__TB-
M-186``!(C7P"_.B9RO__2(N5J/[__X7`2`]%E:#^__](B96@_O__Z7S\___H
M9\K__TB-/>@5```QP.CI]/__9@\?A```````\P\>^E5(C3W7%```2(GE055!
M5$R-;=133(GN2(/L&$B+'?IS``!D2(L$)2@```!(B478,<!D3(LC00^VA"2P
M````08B$)+$````QP.AOY/__2(7`=`F`.#$/A&D!```QP.BJ[___9$R+(TR)
MY[D#````N@$```!(C363%0``Z"W(__])B<1(A<!T*4B+0!!D2(L[2(T5>14`
M`$B+,.@^R/__28M$)!!(BS#V1@Y`#X5,`0``9$B+.[D#````N@$```!(C35/
M%0``Z.+'__])B<1(A<!T+DR)[DB-/=$3```QP.C9X___2(G"2(7`#X3M````
M28M$)!!D2(L[2(LPZ-S'__]D2(L[N@$```!(C34&%0``Z/?&__]D2(L[2(T5
M"Q4``$B)QNBTQ___9$B+`TR)[DB-/6X3``#&@+$`````,<#H>./__TB)!4%S
M``!(B<-(A<!T0;[``0``2(G?Z/S)__^-4`&#^@%V"8/X$0^%F0```$B+1=AD
M2"L$)2@````/A:,```!(@\086T%<05U=PP\?1```2(L]^7(``.A\]O__2(D%
MY7(``$B)PTB%P'6D2(T]'A4``#'`Z-_(__\/'X``````@'@!``^$F/[__^F(
M_O__9@\?A```````2(L%L7(``$B+,$F+1"002(LXZ!GF___I"/___P\?0`!D
M2(L[Z#?(___IIO[__XG!2(L%@7(``$B)VDB-/=\4``!(BS`QP.AUR/__Z"#(
M___S#Q[Z54B)Y4%44TB-=>1(B?M(C3VV$@``2(/L$&1(BP0E*````$B)1>@Q
MP.A?XO__2(7`=!P/MA"`^C`/E,"$T@^4P@C0=0I(A=MT!8`[`'4>2(M%Z&1(
M*P0E*````'5Q2(/$$%M!7%W#9@\?1```2(G?Z!CL__^^+P```$B)QTF)Q.CX
MQO__2(U0`4B%P$P/1>),B>?H9<?__[H$````2(TU\A(``$B)Q^BAQ?__A<!U
MGTB+1>AD2"L$)2@```!U$$B#Q!!(B=];05Q=Z2[C___H2<?__V8/'X0`````
M`/,/'OI5OX````!(B>7H;L7__V8/;P6V40``2,=`,``````/$0!F#V\%LU$`
M`,=`>``````/$4`09@]O!;!1```/$4`@7<-F+@\?A```````\P\>^E5(8\)(
MB>5!5TF)_T%628G&055!5$V-9SA32(GS2(/L&$B+?RA)BU<PC33'2#G^28EW
M*$B#T@!(P>@=2`'028E',$EC1WB%P`^%]@```$&#_C\/CCP!``!!@^Y`1(GP
MP>@&1(UH`8E%R$G!Y09)`=T/'T``\P]O`TR)_TB#PT!!#Q$$)/,/;TO000\1
M3"00\P]O4^!!#Q%4)"#S#V];\$$/$5PD,.ABRO__3#GK=<6+1<C!X`9!*<9)
M8\9(@_@(<EM)BU4`28UW0$B#YOA)B5<X28M4!?A)B50$^$DI]$P!X$TIY4B#
MX/A(@_@(<AA(@^#X,=))BWP5`$B)/!9(@\((2#G"<NY%B7=X2(/$&%M!7$%=
M05Y!7UW##Q\`J`1U?$B%P'3A00^V50!!B%<XJ`)TU$$/MU0%_F9!B50$_NO&
M#Q]``+I`````28T\!$B)WBG"1#GR00]/UD&)U4ACTDB)5<CH=,;__T&+1WA$
M`>A!B4=X@_A`=9)(BT7(3(G_12GN2`'#Z(+)___IO_[__P\?1```28G=Z1S_
M__]!BU4`08E7.$&+5`7\08E4!/SI4____V8/'X0``````/,/'OI52(GE05=,
MC7XX059!54%428G\4TB)\TB#[`A,BW8H3(MN,$R)\$C!Z`.#X#^-4`'&1`8X
M@$ACRH/Z.`^.NP$``+Y`````3`'Y*=9T#S'`B<*#P`'&!!$`.?!R\TB)W^CH
MR/__9@_OP`\10SA)QT<P`````$$/$4<000\11R!,B>I!#[;&38GP3(GW2,'J
M&$C!X`A,B>E)P>@028G13(GR2,'O&`^V]DR)ZDC!Z1!("?!!#[;P#[;)2,'@
M"$@)\$`/MO=(B=](P>`(2`GP00^V]4C!X`A("?`/MO9!#[;12,'@"$@)\$C!
MX`A("<A(P>`(2`G02(E#<.A/R/__2(L#2(G?2,'H&$&(!"1(BP-(P>@008A$
M)`%(BP,/ML1!B$0D`DB+`T&(1"0#2(M#"$C!Z!A!B$0D!$B+0PA(P>@008A$
M)`5(BT,(#[;$08A$)`9(BT,(08A$)`=(BT,02,'H&$&(1"0(2(M#$$C!Z!!!
MB$0D"4B+0Q`/ML1!B$0D"DB+0Q!!B$0D"TB+0QA(P>@808A$)`Q(BT,82,'H
M$$&(1"0-2(M#&`^VQ$&(1"0.2(M#&$&(1"0/2(M#($C!Z!A!B$0D$$B+0R!(
MP>@008A$)!%(BT,@#[;$08A$)!)(BT,@08A$)!-(@\0(6T%<05U!7D%?7>D3
MPO__#Q\`N#@```!)`<\Q_RG0@_@(<D=)C4\(B<))QP<`````2<=$%_@`````
M2(/A^$DIST0!^(/@^(/X"`^"1?[__X/@^#'2B=:#P@A(B3PQ.<)R\^DN_O__
M#Q]``*@$=22%P`^$'O[__T'&!P"H`@^$$O[__S'29D&)5`?^Z07^__\/'P!!
MQP<`````0<=$!_P`````Z>W]__]F+@\?A```````D/,/'OI(BPV-;```Z9#`
M___S#Q[Z2(/L"$B#Q`C#````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O<V5L9B]E>&4`+W!R;V,O)6DO
M)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`;'-E96L@9F%I;&5D`')E860@9F%I;&5D
M`$Q$7TQ)0E)!4EE?4$%42`!365-414T`+W1M<`!414U01$E2`%1-4`!54T52
M`%5315).04U%`"4P,G@`)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`<VAO<G0@
M<F5A9``E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U
M+25U)7,`&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-C$`+64`
M+2T````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T
M<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T;R!C<F5A=&4@8V%C
M:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C
M86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````
M``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@
M7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@
M)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!
M4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I
M"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P
M,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\[
M"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E
M("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE
M(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L
M("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T
M:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@
M)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE
M.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W
M,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L
M;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T
M7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*
M;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@
M(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL
M87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J
M7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN
M9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@
M<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E
M860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@
M(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A
M8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C
M:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)
M3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F
M*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E
M="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@
M7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%
M(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE
M(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T
M=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B
M0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*
M)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5]
M(#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R
M;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN
M9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2![
M"F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z
M:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?
M<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG
M;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII
M9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@
M)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD
M;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@
M)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L
M<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H
M)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I
M.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[
M)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@
M;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@
M:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)
M0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z
M.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP*
M*2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F
M:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@
M*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@
M)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D
M;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O
M<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA
M3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@
M6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I
M.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L
M<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>
M7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI
M)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A
M8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO
M<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N
M="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@
M)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;
M5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*
M?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.
M(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C
M='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE
M(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY
M("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC
M;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T
M(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N
M*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US
M(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG
M('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E
M;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M
M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M
M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I
M<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M
M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD
M8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF
M("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD
M8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@
M*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@
M)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!#04-(10``<&5R;'AS:2YC````
M`````/____\`````_____P`````!(T5G`````(FKS>\`````_MRZF`````!V
M5#(0`````/#ATL,````````````````!&P,[!`$``!\```!@;___.`$``.!R
M__]@`0``\'+__W@!``!@=O__"`4``'!X__\@`0``8'G__Y`!``"PC___P`$`
M`)"0___L`0``()'__Q`"``"@DO__/`(```"3__]<`@``X)/__X@"```PEO__
MN`(``&"6___,`@``0)?___0"``!0E___"`,``'"9__\T`P``L)G__U0#````
MF___A`,``&"?__^T`P``T)___]@#``"0H/__]`,``-"A__\<!```\*'__SP$
M```0H___=`0``/"J__^L!```(*W__]@$````KO__,`4``%"N__]0!0``$+#_
M_X`%``"PLO__L`4````````4``````````%Z4@`!>!`!&PP'")`!```4````
M'````$AW__\F`````$0'$``````D````-````"!N__^``P````X01@X82@\+
M=PB``#\:.2HS)"(`````%````%P```!X<?__$```````````````%````'0`
M``!P<?__<`,`````````````+````(P```#(=___0Q8```!!#A"&`DH-!F&/
M`XX$C06,!H,'`Q$6"@P'"$$+````*````+P```#HC?__U`````!!#A"&`D,-
M!DV/`XX$C06,!H,'`G8*#`<(20L@````Z````)R.__^$`````$$.$(8"0PT&
M08,#`GD*#`<(00LH````#`$```B/__]T`0```$$.$(8"0PT&4(\#C@2-!8P&
M@P<"0`H,!PA$"QP````X`0``7)#__UL`````10X0A@)1#09%@P-X#`<(*```
M`%@!``"<D/__X`````!!#A"&`D,-!E>.`XT$C`6#!@)^"@P'"$<+```L````
MA`$``%"1__]!`@```$$.$(8"0PT&1H\#C@2-!4:,!H,'`R,!"@P'"$4+```0
M````M`$``'"3__\I`````````"0```#(`0``C)/__]T`````10X0A@)##09A
MC0.,!(,%`JX*#`<(00L0````\`$``$24__\)`````````"@````$`@``0)3_
M_Q("````10X0A@)##09<CP..!(T%C`:#!P)R"@P'"$H+'````#`"```TEO__
M,@````!%#A"&`D@-!D&#`U\,!P@L````4`(``%26__]!`0```$4.$(8"0PT&
M4XP#@P0"WPH,!PA&"V$*#`<(3PL````L````@`(``'27__];!````$4.$(8"
M0PT&2(\#C@2-!8P&2(,'`Q0$"@P'"$4+```@````L`(``*2;__]I`````$4.
M$(8"2@T&`D<*#`<(2@L````8````U`(``/";___``````$4.$(8"0PT&````
M)````/`"``"4G/__-@$```!!#A"&`D,-!F*-`XP$@P4"S0H,!PA%"QP````8
M`P``K)W__QX`````10X0A@)##095#`<(````-````#@#``"LG?__&0$```!%
M#A"&`D,-!DJ/`XX$C05)C`9+@P<"2@H,!PA("VT*#`<(2PL````T````<`,`
M`)2>___7!P```$4.$(8"5@T&1(\#C@16C06,!H,'`_X""@P'"$4+`_P""@P'
M"$P+`"@```"H`P``/*;__S`"````10X0A@)*#09$C0.,!$R#!0-S`0H,!PA&
M"P``+````-0#``!`J/__UP````!%#A"&`D,-!D>,`X,$`EH*#`<(1PL"70H,
M!PA%"P``)`````0$``!0<?__#@(```!%#A"&`D,-!D>,`X,$`VH!"@P'"$$+
M`!P````L!```R*C__T8`````10X0A@)(#09X#`<(````+````$P$``#XJ/__
MMP$```!%#A"&`D8-!D*/`T6.!$>-!8P&18,'`OX*#`<(1`L`+````'P$``"(
MJO__E0(```!%#A"&`D,-!D*/`TJ.!(T%C`9$@P<#X`$*#`<(2`L`$````*P$
M``#XK/__$```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````!`J````````T"D````````!`````````.\"`````````0````````#_
M`@````````P``````````"`````````-`````````(!C````````&0``````
M``#`RP```````!L`````````"``````````:`````````,C+````````'```
M```````(`````````/7^_V\`````L`,````````%`````````'@-````````
M!@````````"0!`````````H`````````B`0````````+`````````!@`````
M````%0````````````````````,`````````T,T````````"`````````"@%
M````````%``````````'`````````!<`````````P!0````````'````````
M`$`3````````"`````````"``0````````D`````````&``````````>````
M``````@`````````^___;P`````!```(`````/[__V\`````P!(```````#_
M__]O``````$`````````\/__;P``````$@```````/G__V\`````!```````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-#+````````
M`````````````````````#`@````````0"````````!0(````````&`@````
M````<"````````"`(````````)`@````````H"````````"P(````````,`@
M````````T"````````#@(````````/`@`````````"$````````0(0``````
M`"`A````````,"$```````!`(0```````%`A````````8"$```````!P(0``
M`````(`A````````D"$```````"@(0```````+`A````````P"$```````#0
M(0```````.`A````````\"$`````````(@```````!`B````````("(`````
M```P(@```````$`B````````4"(```````!@(@```````'`B````````@"(`
M``````"0(@```````*`B````````L"(```````#`(@```````-`B````````
MX"(```````#P(@`````````C````````$",````````@(P```````#`C````
M````0",```````!0(P```````&`C````````<",```````"`(P```````)`C
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(T`````````I005(N<&T*``````````#X
M<@```````$=#0SH@*%5B=6YT=2`Q,RXR+C`M,C-U8G5N='4S*2`Q,RXR+C``
M`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YP<F]P97)T>0`N;F]T92YG
M;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`
M+G)E;&$N<&QT`"YI;FET`"YP;'0N9V]T`"YP;'0N<V5C`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`
M+F9I;FE?87)R87D`+F1Y;F%M:6,`+F1A=&$`+F)S<P`N8V]M;65N=```````
M````````````````````````````````````````````````````````````
M````````````````````"P````$````"`````````!@#````````&`,`````
M```<`````````````````````0```````````````````!,````'`````@``
M```````X`P```````#@#````````,`````````````````````@`````````
M```````````F````!P````(`````````:`,```````!H`P```````"0`````
M```````````````$````````````````````.0````<````"`````````(P#
M````````C`,````````@````````````````````!```````````````````
M`$<```#V__]O`@````````"P`P```````+`#````````X``````````&````
M``````@```````````````````!1````"P````(`````````D`0```````"0
M!````````.@(````````!P````$````(`````````!@`````````60````,`
M```"`````````'@-````````>`T```````"(!````````````````````0``
M`````````````````&$```#___]O`@``````````$@`````````2````````
MO@`````````&``````````(``````````@````````!N````_O__;P(`````
M````P!(```````#`$@```````(``````````!P````$````(````````````
M````````?0````0````"`````````$`3````````0!,```````"``0``````
M``8`````````"``````````8`````````(<````$````0@````````#`%```
M`````,`4````````*`4````````&````&`````@`````````&`````````"1
M`````0````8``````````"``````````(````````!L`````````````````
M```$````````````````````C`````$````&`````````"`@````````("``
M``````"``P``````````````````$``````````0`````````)<````!````
M!@````````"@(P```````*`C````````$````````````````````!``````
M````$`````````"@`````0````8`````````L",```````"P(P```````'`#
M```````````````````0`````````!``````````J0````$````&````````
M`"`G````````("<```````!@/```````````````````$```````````````
M`````*\````!````!@````````"`8P```````(!C````````#0``````````
M``````````0```````````````````"U`````0````(``````````'``````
M````<````````,!````````````````````0````````````````````O0``
M``$````"`````````,"P````````P+`````````$`0``````````````````
M!````````````````````,L````!`````@````````#(L0```````,BQ````
M````P`0```````````````````@```````````````````#5````#@````,`
M````````P,L```````#`NP````````@````````````````````(````````
M``@`````````X0````\````#`````````,C+````````R+L````````(````
M````````````````"``````````(`````````.T````&`````P````````#0
MRP```````-"[``````````(````````'``````````@`````````$```````
M``";`````0````,`````````T,T```````#0O0```````#`"````````````
M```````(``````````@`````````]@````$````#``````````#0````````
M`,`````````H````````````````````"````````````````````/P````(
M`````P`````````HT````````"C`````````*`````````````````````@`
M```````````````````!`0```0```#`````````````````````HP```````
M`"8````````````````````!``````````$``````````0````,`````````
M````````````````3L`````````*`0```````````````````0``````````
'````````````
